@@ -1,4 +1,3 @@
-// vim: ts=2 sw=2 et
 /*
  * These tests are of limited usefulness.  In fact, you might even say that
  * they're not really tests at all.  But I felt that it would be useful to have
@@ -8,9 +7,10 @@
 
 #include <cfloat>
 #include <stdexcept>
+#include <iostream>
 #include <boost/test/unit_test.hpp>
 #include <boost/test/test_tools.hpp>
-#include <boost/test/floating_point_comparison.hpp>
+#include <boost/test/tools/floating_point_comparison.hpp>
 using namespace boost::unit_test;
 #include <cairomm/fontface.h>
 #include <cairomm/scaledfont.h>
@@ -24,7 +24,7 @@ struct TestSetup
 {
   TestSetup()
   {
-    surface = ImageSurface::create(Cairo::FORMAT_ARGB32, 100, 100);
+    surface = ImageSurface::create(Cairo::Surface::Format::ARGB32, 100, 100);
     cr = Cairo::Context::create(surface);
   }
 
@@ -40,7 +40,7 @@ public:
     render_glyph(const RefPtr<ScaledFont>& /*scaled_font*/,
                  unsigned long /*glyph*/,
                  const RefPtr<Context>& /*cr*/,
-                 TextExtents& /*metrics*/)
+                 TextExtents& /*metrics*/) override
     { ++count_render_glyph; return CAIRO_STATUS_SUCCESS; }
 
   int count_render_glyph;
@@ -55,7 +55,7 @@ protected:
 class ImplTextUserFont: public NullRenderUserFont
 {
 public:
-  static RefPtr<ImplTextUserFont> create() { return make_refptr_for_insance<ImplTextUserFont>(new ImplTextUserFont());};
+  static RefPtr<ImplTextUserFont> create() { return make_refptr_for_instance<ImplTextUserFont>(new ImplTextUserFont());};
   ErrorStatus text_to_glyphs(const RefPtr<ScaledFont>& /*scaled_font*/,
                                      const std::string& /*utf8*/,
                                      std::vector<Glyph>& glyphs,
@@ -74,7 +74,9 @@ protected:
   ImplTextUserFont() : count_text_to_glyphs(0) {}
 };
 
-void test_implement_text()
+BOOST_AUTO_TEST_SUITE( Cairo_UserFontFace )
+
+BOOST_AUTO_TEST_CASE(test_implement_text)
 {
   TestSetup setup;
   auto font = ImplTextUserFont::create();
@@ -101,7 +103,7 @@ protected:
   ImplUnicodeUserFont() : NullRenderUserFont(), count_unicode_to_glyph(0) {}
 };
 
-void test_implement_unicode()
+BOOST_AUTO_TEST_CASE(test_implement_unicode)
 {
   TestSetup setup;
   auto font = ImplTextUserFont::create();
@@ -143,7 +145,7 @@ protected:
   count_text_to_glyphs(0) {}
 };
 
-void test_implement_both()
+BOOST_AUTO_TEST_CASE(test_implement_both)
 {
   TestSetup setup;
   auto font = ImplBothUserFont::create();
@@ -167,7 +169,7 @@ protected:
   ImplNeitherUserFont() : NullRenderUserFont() {}
 };
 
-void test_implement_neither()
+BOOST_AUTO_TEST_CASE(test_implement_neither)
 {
   TestSetup setup;
   auto font = ImplNeitherUserFont::create();
@@ -194,7 +196,7 @@ protected:
   ImplInitUserFont() : NullRenderUserFont(), count_init(0) {}
 };
 
-void test_implement_init()
+BOOST_AUTO_TEST_CASE(test_implement_init)
 {
   TestSetup setup;
   auto font = ImplInitUserFont::create();
@@ -213,7 +215,7 @@ public:
   render_glyph(const RefPtr<ScaledFont>& /*scaled_font*/,
                unsigned long /*glyph*/,
                const RefPtr<Context>& /*cr*/,
-               TextExtents& /*metrics*/)
+               TextExtents& /*metrics*/) override
   {
     count_render_glyph++;
     if (m_flags & FLAG_RENDER)
@@ -224,7 +226,7 @@ public:
   ErrorStatus
   unicode_to_glyph(const RefPtr<ScaledFont>& /*scaled_font*/,
                                        unsigned long unicode,
-                                       unsigned long& glyph)
+                                       unsigned long& glyph) override
   {
     count_unicode_to_glyph++;
     if (m_flags & FLAG_UNICODE)
@@ -261,7 +263,7 @@ protected:
   m_flags(flags) {}
 };
 
-void test_user_font_exception()
+BOOST_AUTO_TEST_CASE(test_user_font_exception)
 {
   auto font =
     ExceptionUserFont::create(ExceptionUserFont::FLAG_INIT);
@@ -313,21 +315,4 @@ void test_user_font_exception()
   BOOST_CHECK (font->count_render_glyph > 0);
 }
 
-
-test_suite*
-init_unit_test_suite(int argc, char* argv[])
-{
-  // compile even with -Werror
-  if (argc && argv) {}
-
-  test_suite* test= BOOST_TEST_SUITE( "Cairo::UserFontFace Tests" );
-
-  test->add (BOOST_TEST_CASE (&test_implement_text));
-  test->add (BOOST_TEST_CASE (&test_implement_unicode));
-  test->add (BOOST_TEST_CASE (&test_implement_both));
-  test->add (BOOST_TEST_CASE (&test_implement_neither));
-  test->add (BOOST_TEST_CASE (&test_implement_init));
-  test->add (BOOST_TEST_CASE (&test_user_font_exception));
-
-  return test;
-}
+BOOST_AUTO_TEST_SUITE_END()
